<?php
	/**
	 * WC comnpay Gateway Class.
	 * Built the comnpay method.
	*/
	class WC_ComNpay extends WC_Payment_Gateway {
		/**
		 * Constructor for the gateway.
		 *
		 * @return void
		 */
		public function __construct() {
			
			global $woocommerce;
	
			$this->id = 'comnpay';
			$this->icon = apply_filters( 'woocommerce_comnpay_icon', '' );
			$this->has_fields = false;
			$this->method_title = __( 'ComNpay', 'comnpay' );
	
			// Load the form fields.
			$this->init_form_fields();
	
			// Load the settings.
			$this->init_settings();
	
			// Define user set variables.
			$this->title = $this->settings['title'];
			$this->description = $this->settings['description'];
			$this->instructions = $this->get_option('instructions');
			$this->comnpay_gateway_tpe_number = $this->settings['comnpay_gateway_tpe_number'];
			$this->comnpay_gateway_secret_key = $this->settings['comnpay_gateway_secret_key'];
			$this->comnpay_gateway_url_homologation = $this->settings['comnpay_gateway_url_homologation'];
			$this->comnpay_gateway_url_production = $this->settings['comnpay_gateway_url_production'];
			$this->comnpay_gateway_url_retour_ok = $this->settings['comnpay_gateway_url_retour_ok'];
			$this->comnpay_gateway_url_retour_nok = $this->settings['comnpay_gateway_url_retour_nok'];
			$this->comnpay_gateway_plateforme = $this->settings['comnpay_gateway_plateforme'];
			$this->comnpay_gateway_payment_debit = $this->settings['comnpay_gateway_payment_debit'];
			$this->comnpay_gateway_payment_pre_auth = $this->settings['comnpay_gateway_payment_pre_auth'];
			$this->comnpay_gateway_payment_p3f = $this->settings['comnpay_gateway_payment_p3f'];
			$this->comnpay_gateway_minimum_p3f = $this->settings['comnpay_gateway_minimum_p3f'];
			
	
			// Actions.
			if(version_compare(WOOCOMMERCE_VERSION, '2.0.0', '>=')) {
				add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( &$this, 'process_admin_options' ) );
			}else{
				add_action( 'woocommerce_update_options_payment_gateways', array( &$this, 'process_admin_options' ) );
			}
		}
	
		/* Admin Panel Options.*/
		
		function admin_options() {
			$arrayLang = array('fr', 'en');
			$langIso = substr(get_bloginfo ( 'language' ), 0, 2);
			if(!in_array($langIso, $arrayLang)){
				$langIso = 'en';
			}

			$arrayLangValue = array(
				'fr' => array(
					'titre'			=> 'Accepte les paiements par CB avec comNpay',
					'explication_1'	=> 'ComNpay est une solution de paiement sécurisé sur Internet. Véritable TPE (Terminal de Paiement Electronique) Virtuel, ComNpay permet d\'encaisser les paiements réalisés sur Internet 24 heures sur 24, 7 jours sur 7. Ce service, décharge votre site de toute la phase de paiement ; cette dernière a lieu directement sur notre plateforme de paiement sécurisé.',
					'explication_2'	=> 'Pour tout problèmes ou informations contactez : technique@comnpay.com',
					'compte'		=> 'Obtenir un compte ComNpay',
					'tester'		=> 'Tester gratuitement',
					'site'			=> 'Site officiel',
					'doc'			=> 'Documentation'
				),
				'en' => array(
					'titre'			=> 'Accepts payments by credit card with comNpay',
					'explication_1'	=> 'ComNpay is a secure payment solution on the Internet. As a virtual POS (Electronic Payment Terminal), ComNpay makes it possible to cash payments made on the Internet 24 hours a day, 7 days a week. This service relieves your site of the entire payment phase; the latter takes place directly on our secure payment platform.',
					'explication_2'	=> 'For any problem or information contact: technique@comnpay.com',
					'compte'		=> 'Get a ComNpay account',
					'tester'		=> 'Test free',
					'site'			=> 'Official site',
					'doc'			=> 'Documentation'
				),

			)


			?>
			<h3><?php _e('ComNpay configuration','comnpay'); ?></h3>
            <div class="simplify-commerce-banner updated">
            	<img src="<?php echo get_site_url().'/wp-content/plugins/woocommerce-comnpay/assets/img/comnpay.png';?>" />
				<p class="main"><strong><?php echo $arrayLangValue[$langIso]['titre'];?></strong></p>
				<p><?php echo $arrayLangValue[$langIso]['explication_1'];?></p>
                <p><?php echo $arrayLangValue[$langIso]['explication_2'];?></p>

				<p><a href="https://comnpay.com/fr/offres" target="_blank" class="button button-primary"><?php echo $arrayLangValue[$langIso]['compte'];?></a> <a href="https://homologation.comnpay.com/inscription.html" target="_blank" class="button"><?php echo $arrayLangValue[$langIso]['tester'];?></a> <a href="https://www.comnpay.com/" target="_blank" class="button"><?php echo $arrayLangValue[$langIso]['site'];?></a> <a href="https://docs.comnpay.com/" target="_blank" class="button"><?php echo $arrayLangValue[$langIso]['doc'];?></a></p>

			</div>
			<table class="form-table">
				<?php $this->generate_settings_html(); ?>
			</table>
			<?php
		}
	
		/* Initialise Gateway Settings Form Fields. */
	   
		public function init_form_fields() {
			
			global $woocommerce;
			$arrayLang = array('fr', 'en');
			$langIso = substr(get_bloginfo ( 'language' ), 0, 2);
			if(!in_array($langIso, $arrayLang)){
				$langIso = 'en';
			}

			$arrayLangValue = array(
				'fr' => array(
					'enabled_title'								=> 'Activer/Désactiver',
					'enabled_label'								=> 'Activer les paiements par CB avec ComNpay',
					'title_title'								=> 'Titre',
					'title_label'								=> 'Paiement sécurisé ComNpay',
					'title_default'								=> 'Payer par carte',
					'description_title'							=> 'Message avant paiement',
					'description_label'							=> 'Message avant la redirection vers la page de paiement',
					'description_description'					=> 'Vous allez être redirigé vers ComNpay pour régler vos achats en toute sécurité',
					'instructions_title'						=> 'Message après règlement',
					'instructions_label'						=> 'Message sur la page de remerciement',
					'instructions_description'					=> 'Votre commande est validée. Merci de votre confiance.',
					'comnpay_gateway_tpe_number'				=> 'Numéro de TPE',
					'comnpay_gateway_secret_key'				=> 'Clé secrète',
					'comnpay_gateway_url_homologation'			=> 'URL Homologation',
					'comnpay_gateway_url_production'			=> 'URL Production',
					'comnpay_gateway_plateforme'				=> 'Plateforme',
					'comnpay_gateway_url_retour_ok_label'		=> 'URL OK',
					'comnpay_gateway_url_retour_ok_title'		=> 'Indiquez la page de retour pour une transaction réalisée',
					'comnpay_gateway_url_retour_nok_label'		=> 'URL NOK',
					'comnpay_gateway_url_retour_nok_title'		=> 'Indiquez la page de retour pour une transaction non réalisée',
					'comnpay_gateway_payment_debit_label'		=> 'Paiement classic',
					'activer'									=> 'Activer',
					'comnpay_gateway_payment_pre_auth_label'	=> 'Paiement pré-autorisé',
					'comnpay_gateway_payment_p3f_label'			=> 'Paiement en 3 fois',
					'comnpay_gateway_minimum_p3f'				=> 'Montant minimum pour le paiement en 3 fois (Minimum 50€)'
				),
				'en' => array(
					'enabled_title'								=> 'Enable / Disable',
					'enabled_label'								=> 'Activate CB payments with ComNpay',
					'title_title'								=> 'Title',
					'title_label'								=> 'ComNpay secure payment',
					'title_default'								=> 'Pay by card',
					'description_title'							=> 'Message before payment',
					'description_label'							=> 'Message before redirecting to the payment page',
					'description_description'					=> 'You will be redirected to ComNpay to pay for your purchases safely',
					'instructions_title'						=> 'Message after payment',
					'instructions_label'						=> 'Message on the thank you page',
					'instructions_description'					=> 'Your order is validated. Thank you for your confidence.',
					'comnpay_gateway_tpe_number'				=> 'Serial number TPE',
					'comnpay_gateway_secret_key'				=> 'Secret key',
					'comnpay_gateway_url_homologation'			=> 'Homologation URL',
					'comnpay_gateway_url_production'			=> 'Production URL',
					'comnpay_gateway_plateforme'				=> 'Plateform',
					'comnpay_gateway_url_retour_ok_label'		=> 'URL OK',
					'comnpay_gateway_url_retour_ok_title'		=> 'Indicate the return page for a completed transaction',
					'comnpay_gateway_url_retour_nok_label'		=> 'URL KO',
					'comnpay_gateway_url_retour_nok_title'		=> 'Indicate the return page for an unrealized transaction',
					'comnpay_gateway_payment_debit_label'		=> 'Classic payment',
					'activer'									=> 'Enable',
					'comnpay_gateway_payment_pre_auth_label'	=> 'Pre-authorized payment',
					'comnpay_gateway_payment_p3f_label'			=> 'Payment in 3 times',
					'comnpay_gateway_minimum_p3f'				=> 'Minimum amount for payment in 3 times (Minimum 50 €)'
				)
			);
			
			$this->form_fields = array(
				'enabled' => array(
					'title'		=> __( $arrayLangValue[$langIso]['enabled_title'], 'comnpay' ),
					'type'		=> 'checkbox',
					'label' 	=> __( $arrayLangValue[$langIso]['enabled_label'], 'comnpay' ),
					'default' 	=> 'no'
				),
				'title' => array(
					'title' 		=> __( $arrayLangValue[$langIso]['title_title'], 'comnpay' ),
					'type' 			=> 'text',
					'description' 	=> __( $arrayLangValue[$langIso]['title_label'], 'comnpay' ),
					'desc_tip' 		=> true,
					'default' 		=> __( $arrayLangValue[$langIso]['title_default'] )
				),
				'description' => array(
					'title' 		=> __( $arrayLangValue[$langIso]['description_title'], 'comnpay' ),
					'type' 			=> 'textarea',
					'description' 	=> __( $arrayLangValue[$langIso]['description_label'], 'comnpay' ),
					'default' 		=> __( $arrayLangValue[$langIso]['description_description'], 'comnpay' )
				),
				'instructions' => array(
					'title' 		=> __( $arrayLangValue[$langIso]['instructions_title'], 'comnpay' ),
					'type' 			=> 'textarea',
					'description' 	=> __( $arrayLangValue[$langIso]['instructions_label'], 'comnpay' ),
					'default' 		=> __( $arrayLangValue[$langIso]['description_description'], 'comnpay' )
				),
				'comnpay_gateway_tpe_number' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_tpe_number'], 'comnpay' ),
					'type' 		=> 'text'
				),
				'comnpay_gateway_secret_key' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_secret_key'], 'comnpay' ),
					'type' 		=> 'text'
				),
				'comnpay_gateway_url_homologation' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_url_homologation'], 'comnpay' ),
					'type' 		=> 'text',
					'default'	=> 'https://secure-homologation.comnpay.com'
				),
				'comnpay_gateway_url_production' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_url_production'], 'comnpay' ),
					'type' 		=> 'text',
					'default'	=> 'https://secure.comnpay.com'
				),
				'comnpay_gateway_plateforme' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_plateforme'], 'comnpay' ),
					'type' 		=> 'select',
					'default' 	=> 'homologation',
					'options'	=> array(
									'homologation'	=> 'Homologation',
									'production'	=> 'Production'
								)
				),
				'comnpay_gateway_url_retour_ok' => array(
					'title' 		=> __( $arrayLangValue[$langIso]['comnpay_gateway_url_retour_ok_label'], 'comnpay' ),
					'type' 			=> 'text',
					'description'	=> $arrayLangValue[$langIso]['comnpay_gateway_url_retour_ok_title']
				),
				'comnpay_gateway_url_retour_nok' => array(
					'title' 		=> __( $arrayLangValue[$langIso]['comnpay_gateway_url_retour_nok_label'], 'comnpay' ),
					'type' 			=> 'text',
					'description'	=> $arrayLangValue[$langIso]['comnpay_gateway_url_retour_nok_label']
				),
				'comnpay_gateway_payment_debit' => array(
					'title'		=> __( $arrayLangValue[$langIso]['comnpay_gateway_payment_debit_label'], 'comnpay' ),
					'type'		=> 'checkbox',
					'label' 	=> __( $arrayLangValue[$langIso]['activer'], 'comnpay' ),
					'default' 	=> 'yes'
				),
				'comnpay_gateway_payment_pre_auth' => array(
					'title'		=> __( $arrayLangValue[$langIso]['comnpay_gateway_payment_pre_auth_label'], 'comnpay' ),
					'type'		=> 'checkbox',
					'label' 	=> __( $arrayLangValue[$langIso]['activer'], 'comnpay' ),
					'default' 	=> 'no'
				),
				'comnpay_gateway_payment_p3f' => array(
					'title'		=> __( $arrayLangValue[$langIso]['comnpay_gateway_payment_p3f_label'], 'comnpay' ),
					'type'		=> 'checkbox',
					'label' 	=> __( $arrayLangValue[$langIso]['activer'], 'comnpay' ),
					'default' 	=> 'no'
				),
				'comnpay_gateway_minimum_p3f' => array(
					'title' 	=> __( $arrayLangValue[$langIso]['comnpay_gateway_minimum_p3f'], 'comnpay' ),
					'type' 		=> 'text',
					'default'	=> '50'
				)
			);
		}
	
		/* Process the payment and return the result. */
		
		function process_payment($order_id) {
			global $woocommerce;
			// Return redirect
			return array(
				'result' 	=> 'success',
				'redirect'	=> plugins_url('woocommerce-comnpay/process.php?idTransaction='.$order_id, dirname(__FILE__))
			);
		}
	
		/* Output for the order received page.   */
		
		function thankyou() {
			echo $this->instructions != '' ? wpautop( $this->instructions ) : '';
		}
		
		// ComNpay Default functions
		
		public function totalTypeTrActive() {
			$iTotal = 0;
			if($this->comnpay_gateway_payment_debit == "yes") {
				$iTotal++;
			}
			if($this->comnpay_gateway_payment_pre_auth == "yes") {
				$iTotal++;
			}
			if($this->comnpay_gateway_payment_p3f == "yes") {
				$iTotal++;
			}
			return $iTotal;
		}
		
		public function getComnpayConfig($idOrder) {
			$COMNPAY_CONFIG = array();
			$COMNPAY_CONFIG['tpe_number'] = $this->get_option('comnpay_gateway_tpe_number');
			$COMNPAY_CONFIG['secret_key'] = $this->get_option('comnpay_gateway_secret_key');
			if($this->get_option('comnpay_gateway_plateforme') == "production") {
				$COMNPAY_CONFIG['plateforme'] = $this->get_option('comnpay_gateway_url_production');
			}else{
				$COMNPAY_CONFIG['plateforme'] = $this->get_option('comnpay_gateway_url_homologation');
			}
			if($this->get_option('comnpay_gateway_url_retour_ok') !== "") {
				$COMNPAY_CONFIG['url_retour_ok'] = $this->get_option('comnpay_gateway_url_retour_ok');
			}else{
				$COMNPAY_CONFIG['url_retour_ok'] = get_site_url();
			}
			if($this->get_option('comnpay_gateway_url_retour_nok') !== "") {
				$COMNPAY_CONFIG['url_retour_nok'] = $this->get_option('comnpay_gateway_url_retour_nok');
				$COMNPAY_CONFIG['url_retour_checkout'] = $this->get_option('comnpay_gateway_url_retour_nok');
			}else{
				$COMNPAY_CONFIG['url_retour_nok'] = get_site_url();
				$COMNPAY_CONFIG['url_retour_checkout'] = wc_get_checkout_url();
			}
			$COMNPAY_CONFIG['url_retour_ipn'] = get_site_url().'/wp-content/plugins/woocommerce-comnpay/ipn.php';
			$COMNPAY_CONFIG['product_name'] = 'Commande '.intval($idOrder);
			return $COMNPAY_CONFIG;
		}
		
	}
?>